@@ -3,10 +3,11 @@ from .base_dgp import BaseDataGenusProcessor
 
 class ConfigurableDGP(BaseDataGenusProcessor):
 
-    def init(self, kind):
+    def init(self, kind, per_taxonomy=True):
         self._flows = None
         self._analyzers = None
         self._kind = kind
+        self._per_taxonomy = per_taxonomy
 
     def analyze(self):
         if self.analyzers is not None:
@@ -15,17 +16,20 @@ class ConfigurableDGP(BaseDataGenusProcessor):
 
     @property
     def module(self):
-        return getattr(self.context.taxonomy, self._kind)
+        if self._per_taxonomy:
+            return getattr(self.context.taxonomy, self._kind)
+        else:
+            return getattr(self.context.taxonomies.get('_common_'), self._kind)
 
     @property
     def flows(self):
-        if self._flows is None:
+        if self.module is not None and self._flows is None:
             self._flows = self.module.flows(self.config, self.context)
         return self._flows
 
     @property
     def analyzers(self):
-        if self._analyzers is None:
+        if self.module is not None and self._analyzers is None:
             self._analyzers = self.module.analyzers(self.config, self.context) or []
             self.steps = self.init_classes(self._analyzers)
         return self._analyzers
